pub enum Error {
SerdeJsonError(Error),
SerdePathError(Error<Error>),
Utf8Error(Utf8Error),
StdIoError(Error),
PathConversionError,
}Expand description
Error type for dotnet_parser
Variants
SerdeJsonError(Error)
This means something went wrong when we were parsing the JSON output of the program
SerdePathError(Error<Error>)
This is a wrapped serde_json error which provides a path to the location where the error occurred
Utf8Error(Utf8Error)
This means the output of the program contained some string that was not valid UTF-8
StdIoError(Error)
This is likely to be an error when executing the program using std::process
PathConversionError
This means that we failed to convert a path into an Utf-8 string